%Gathers data from breve. Requires that breve run Tiny Dancer - cheerleader7DOF.tz This
%is a hard-coded movement designed by me.
%
%[ desired_state, context, header ]  = cheerleader(port)
%
%Inputs:
%
%port: The port number where the breve simulator listens for socket
%connections. If omitted, assumed to be 7777.
%
%Outputs:
%
%desired_state: A matrix holding the desired states of the movement.
%
%context: The context information that goes along with the desired states.
%
%header: A string array describing which joint is moved for each row in the
%desired states matrix. This is used when plotting the performance of the
%multiple model versus the desired state.
function [ desired_state, context, header ]  = cheerleader(port)

if nargin == 0
    port = 7777;
end

num_iterations = 1;

%tic

Breve.read('localhost', port, 'reset');

desired_state = [];


%The mask of the output is: 
%right shoulder x, right shoulder y, left shoulder x, left shoulder y,
%right hip x, right hip y, left hip x.

%Raising both arms
for i=1:30
    desired_state = [desired_state scale_angles(eval(Breve.read('localhost', port, ...
    [ 'execute_' int2str(num_iterations) ...
    '_1_0_1_0_.5_0_-.5' ])))];
end

%Lowering both arms
for i=1:30
    desired_state = [ desired_state scale_angles(eval(Breve.read('localhost', port, ...
    [ 'execute_' int2str(num_iterations) ...
    '_-1_0_-1_0_-.5_0_.5' ] )))]
end


%Rotating both arms and legs
for i=1:20
    desired_state = [desired_state scale_angles(eval(Breve.read('localhost',port, ...
    [ 'execute_' int2str(num_iterations) ...
    '_0_1_0_1_0_-.5_0' ] )))]
end

%And back...
for i=1:20
    desired_state = [desired_state scale_angles(eval(Breve.read('localhost',port, ...
    [ 'execute_' int2str(num_iterations) ...
    '_0_-1_0_-1_0_.5_0' ] )))]
end


%Move legs and arms forward
for i=1:30
   desired_state = [desired_state scale_angles(eval(Breve.read('localhost',port, ...
    [ 'execute_' int2str(num_iterations) ...
    '_1_.4_1_.4_1_0_1' ] )))]
end

%Move legs and arms backward
for i=1:30
   desired_state = [desired_state scale_angles(eval(Breve.read('localhost',port, ...
    [ 'execute_' int2str(num_iterations) ...
    '_-1_-.4_-1_-.4_-1_0_-1' ] )))]
end



%Setting the context values accordingly, now the first movement is
%accompanied by a high value, the second is accompanied by its own high
%value.

%}

context = zeros(3, size(desired_state, 2));
context(1,1:60) = 1;
context(2,61:100) = 1;
context(3,101:160) = 1;


%Generate header data.
header = tokenize([ 'Right shoulder X joint angle.Right shoulder Y joint angle.' ...
'Left shoulder X joint angle.Left shoulder Y joint angle.' ...
'Right hip X joint angle.Right hip Y joint angle.' ...
'Left hip X joint angle.' ], '.');

%toc