%Gathers data from breve. Requires that breve run Tiny Dancer - K4DOF.tz This
%is a hard-coded movement designed by me.
%
%[ desired_state, context, header ]  = Ks(port)
%
%Inputs:
%
%port: The port number where the breve simulator listens for socket
%connections. If omitted, assumed to be 7777.
%
%Outputs:
%
%desired_state: A matrix holding the desired states of the movement.
%
%context: The context information that goes along with the desired states.
%
%header: A string array describing which joint is moved for each row in the
%desired states matrix. This is used when plotting the performance of the
%multiple model versus the desired state.
function [ desired_state, context, header ]  = Ks(port)

if nargin == 0
    port = 7777;
end

tic

num_iterations = 1;

Breve.read('localhost', port, 'reset');

desired_state = [];

%Raising right arm and leg.
for i=1:30
     desired_state = [desired_state scale_angles(eval(Breve.read('localhost', port, ...
    [ 'execute_' int2str(num_iterations) ...
    '_1_0_-1_0' ])))];pause(1);
end

%Lowering right arm and leg
for i=1:30
    desired_state = [desired_state scale_angles(eval(Breve.read('localhost', port, ...
    [ 'execute_' int2str(num_iterations) ...
    '_-1_0_1_0' ])))];pause(1);
end


%Raising left arm and leg
for i=1:30
    desired_state = [desired_state scale_angles(eval(Breve.read('localhost', port, ...
    [ 'execute_' int2str(num_iterations) ...
    '_0_1_0_1' ])))];pause(1);
end

%Lowering left arm and leg
for i=1:30
    desired_state = [desired_state scale_angles(eval(Breve.read('localhost', port, ...
    [ 'execute_' int2str(num_iterations) ...
    '_0_-1_0_-1' ])))];pause(1);
end


%Setting the context values accordingly, now the first movement is
%accompanied by a high value, the second is accompanied by its own high
%value.

%}

context = zeros(2, size(desired_state, 2));
context(1,1:60) = 1;
context(2,61:120) = 1;

%Generate header data

header = tokenize([ 'Right shoulder X joint angle.Left shoulder X joint angle.' ...
    'Right hip Y joint angle.Left hip Y joint angle.' ], '.');

toc