%Loads the tracking data gathered from PRO REFLEX, scales, transposes and extracts every 10 sampling.
%
%The data is based on the third videosegment, starting at 26.41 seconds,
%ending 7 seconds later. In PRO REFLEX, this is found in the file: 
%06 mye bra ymca.qtm, starting at the above mentioned times.
%
%In the tracking of the video, it is the LAST of the YMCA movements
%before stopping recording (which can also be seen from the QTM file).
%
%Requires that breve run Tiny Dancer - YMCA4DOF.tz
%
%[desired_state, context, header] = YMCA4DOF_desired_state
%
%Inputs:
%
%port: The port number where the breve simulator listens for socket
%connections. If omitted, assumed to be 7777.
%
%Outputs:
%
%desired_state: A matrix holding the desired states of the movement.
%
%context: The context information that goes along with the desired states.
%
%header: A string array describing which joint is moved for each row in the
%desired states matrix. This is used when plotting the performance of the
%multiple model versus the desired state.

function [desired_state, context, header] = YMCA4DOF_desired_state


[header, desired_state_raw] = hdrload('YMCA_01_4DOF.txt'); 

%Scale it
desired_state = zeros(size(desired_state_raw));
desired_state(:,1) = scale(-90,90, desired_state_raw(:,1));
desired_state(:,2) = scale(0,180, desired_state_raw(:,2));
desired_state(:,3) = scale(-90,90, desired_state_raw(:,3));
desired_state(:,4) = scale(0,180, desired_state_raw(:,4));

%Transpose it
desired_state = desired_state';

%Create the context data. These are based on extractions I see from the Pro
%Reflex system. Here it determine there will be 4 context signals.

context = zeros(4, length(desired_state));
%First frame: Y:5282 M:5758 C:5879 A:5995 
%Which yields: Y = 1:476
%              M = 477:598
%              C = 599:715
%              A = 716:end

context(1, 1:476) = 1; %Y
context(2, 477:598) = 1; %M
context(3, 599:715) = 1; %C
context(4, 715:end) = 1; %A

%Extract every 10 sample, since the sampling frequency of Pro Reflex is
%200, now there will be 20 samples pr second, matching that of breve.
desired_state = desired_state(:,1:10:end);
context = context(:, 1:10:end);

%String tokenize the header, knowing that tab is the delimiter.
header = tokenize(header, 9);