%Passes desired states through a multiple model. There is no learning
%involved. Typically used to see the performance of a multiple model after
%training.
%
%[ states, mms ] = hybrid_mosaic_run(mm, x_desired, y) 
%
%Inputs: 
%
%mm: The multiple model.  
%
%x_desired: The desired states.  
%
%y: The contextual information.  
%
%Outputs: 
%
%states: The states of the simulator as it passes through the target goals.
%
%mms: The multiple models. These are stored so that neural
%activation levels can be examined later on.


function [ states, mms ] = hybrid_mosaic_run(mm, x_desired, y)

%Logs the states of the simulator. Note that the logging will only start
%*after* the first pass of the goal state. This is to match how well the
%multiple model performs compared to the desired trajectory.
states = [];
mms = [];

%To keep it simple, every simulation should start at the same position. x
%equals state.
x = mm(1).execute([]);

%To initialize the context matrices of the model. 
mm = mm_init_context(mm, x);

%Turn on verbose output, since this is interesting when observing the
%performance.
%mm(1).verbose = true;

execution_time = 0;

for i=1:length(x_desired)
    %Compute the motor commands and the errors of the respective modules.
    [mm, motor_commands, lambda, forw_err, inv_err] = hybrid_mosaic_activate(mm, x, x_desired(:,i), y(:,i));

    
        
    
    %Execute the motor commands. The next time, the state returned from
    %breve will be x_t+1
    x = mm(1).execute(motor_commands);


    
    %Log the current state of the simulator. 
    states = [ states x ];
    %Log the multiple models. Notice how it automatically creates an array
    %of structs, since mm is enclosed in brackets. This way, all the
    %multiple models at one timestep will be stored at one location in the
    %matrix.
    mms = [ mms {mm} ];
end