%The experiment file for the "cheerleader" experiment. This file executes the
%experiment from the MatLab side. The corresponding breve source code file
%(i.e. Tiny Dancer - cheerleader7DOF.tz must run on the breve side. The results are
%stored in a file called cheerleader.mat.

tic

clear all;

epochs = 8000;

[ desired_state, context, header ] = cheerleader;

no_mms = size(context,1);
state_size = size(desired_state,1);

%Parameters to the multiple model.
K = 2;
output_gain = 2;
learning_rate = 0.01;
sigma = 0.2;
error_proportion = 5;


%Create the multiple model.
hybrid_mosaic = multiple_models(no_mms, [2*state_size state_size state_size], [2*state_size state_size state_size],...
    [no_mms no_mms 1], @breve_breve_execute, ...
    K, output_gain, learning_rate, sigma, error_proportion);

disp('starting hybrid_mosaic run...')

for i=1:epochs
    disp(sprintf('epoch %d', i))
    [hybrid_mosaic, err, actual_state] = hybrid_mosaic_train(hybrid_mosaic, desired_state, context);
    hybrid_mosaic_error_log(i).err = err;
    hybrid_mosaic_error_log(i).actual_state = actual_state;
end

%Save the desired_state, context and header to the hybrid_mosaic struct
hybrid_mosaic(1).desired_state = desired_state;
hybrid_mosaic(1).context = context;
hybrid_mosaic(1).header = header;

%Saving the name of this file, and the name of the file that needs to be
%run on the breve simulator.
hybrid_mosaic(1).matlab_file = 'breve_breve_matlab_cheerleader.m';
hybrid_mosaic(1).breve_file = 'Tiny Dancer - cheerleader7DOF.tz';

%Save the time it took to train the multiple model.
hybrid_mosaic(1).training_time = toc;

save cheerleader.mat *mosaic*