%The experiment file for the "YMCA" experiment. This file executes the
%experiment from the MatLab side. The corresponding breve source code file
%(i.e. Tiny Dancer - YMCA4DOF.tz must run on the breve side. The results are
%stored in a file called YMCA4DOF.mat.
%
%The script runs the system on data gathered using the PRO REFLEX system. 

%Clear all variables in memory. 
clear all;

disp('gathering data from PRO REFLEX')

tic

epochs = 12000;

[ desired_state, context, header ] = YMCA4DOF_desired_state;

%The number of multiple models, and the size of the state, i.e. the number
%of joint angles in the simulator. 
no_mms = size(context,1);
state_size = size(desired_state,1);

%Parameters to the multiple model.
K = 3;
output_gain = 3;
learning_rate = 0.01;
sigma = 0.1;
error_proportion = 8;

%Create the multiple model.
hybrid_mosaic = multiple_models(no_mms, [2*state_size state_size state_size], [2*state_size state_size state_size],...
    [no_mms no_mms 1], @breve_breve_execute, ...
    K, output_gain, learning_rate, sigma, error_proportion);

disp('starting hybrid_mosaic run...')

%Iterate and train, logging training information along the way.
for i=1:epochs
    disp(sprintf('epoch %d', i))
    [hybrid_mosaic, err, actual_state] = hybrid_mosaic_train(hybrid_mosaic, desired_state, context);
    hybrid_mosaic_error_log(i).err = err;
    hybrid_mosaic_error_log(i).actual_state = actual_state;
end

%Save the desired_state, context and header to the hybrid_mosaic struct
hybrid_mosaic(1).desired_state = desired_state;
hybrid_mosaic(1).context = context;
hybrid_mosaic(1).header = header;

%Saving the name of this file, and the name of the file that needs to be
%run on the breve simulator.
hybrid_mosaic(1).matlab_file = 'human_breve_matlab_YMCA4DOF.m';
hybrid_mosaic(1).breve_file = 'Tiny Dancer - YMCA4DOF.tz';

%Save the time it took to train the multiple model.
hybrid_mosaic(1).training_time = toc;

%Save the multiple model and the error log for later analysis.
save YMCA4DOF.mat *mosaic*